@@ -27,12 +27,10 @@ VALUES (
 );
 
 INSERT INTO contributors (
-	Users_ID, 
-      username, 
+       username, 
        authlevel
 ) 
 VALUES (
-	1,
        'guest',
        0
 );
